==> nextcloud-22.2.4.tgz: nextcloud/apps/federation/l10n/it.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Aggiunto all'elenco dei server affidabili",
    "Server is already in the list of trusted servers." : "Il server è già nell'elenco dei server affidabili.",
    "No server to federate with found" : "Non ho trovato alcun server per la federazione",
    "Could not add server" : "Impossibile aggiungere il server",
    "Trusted servers" : "Server affidabili",
    "Federation" : "Federazione",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "La federazione consente di connettersi ad altri server affidabili per scambiare la cartella utente.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La federazione consente di connettersi ad altri server affidabili per accedere alla cartella utente. Ad esempio, può essere utilizzata per il completamento automatico di utenti esterni per la condivisione federata.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federazione ti consente di connetterti ad altri server affidabili per accedere alla cartella utente. Ad esempio, può essere utilizzata per il completamento automatico di utenti esterni per la condivisione federata. Non è necessario aggiungere un server come affidabile per creare una condivisione federata.",
    "+ Add trusted server" : "+ Aggiungi server affidabile",
    "Trusted server" : "Server affidabile",
    "Add" : "Aggiungi"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/federation/l10n/it.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Aggiunto all'elenco dei server affidabili",
    "Server is already in the list of trusted servers." : "Il server è già nell'elenco dei server affidabili.",
    "No server to federate with found" : "Non ho trovato alcun server per la federazione",
    "Could not add server" : "Impossibile aggiungere il server",
    "Trusted servers" : "Server affidabili",
    "Federation" : "Federazione",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "La federazione consente di connettersi ad altri server affidabili per scambiare la cartella utente.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La federazione consente di connettersi ad altri server affidabili per accedere alla cartella utente. Ad esempio, può essere utilizzata per il completamento automatico di utenti esterni per la condivisione federata.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "La federazione ti consente di connetterti ad altri server affidabili per accedere alla cartella utente. Ad esempio, può essere utilizzata per il completamento automatico di utenti esterni per la condivisione federata. Non è necessario aggiungere un server come affidabile per creare una condivisione federata.",
    "+ Add trusted server" : "+ Aggiungi server affidabile",
    "Trusted server" : "Server affidabile",
    "Add" : "Aggiungi"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
